@@ -34,7 +34,8 @@ import time
 import datetime
 import calendar
 import email.utils as eut
-
+import pynotify
+import dbus
 
 class account():
 
@@ -46,8 +47,21 @@ class account():
     INACTIVE = 2
     status = ""
     avatar_size = 60
+    _MCE_SERVICE = 'com.nokia.mce'
+    _MCE_REQUEST_PATH = '/com/nokia/mce/request'
+    _MCE_REQUEST_IF = 'com.nokia.mce.request'
+    _ENABLE_LED = 'req_led_pattern_activate'
+    _DISABLE_LED = 'req_led_pattern_deactivate'
+    _VIBRATE  = 'req_vibrator_pattern_activate'
+    _VIBRATE_PATTERN= 'PatternChatAndEmail'
+    _LED_PATTERN = 'PatternCommunicationIM'
+
+
 
     def __init__(self, osso_c, accData, controller):
+        pynotify.init("Witter")
+        self.bus = dbus.SystemBus()
+
         self.controller = controller
         #these store all the data associated with this accounts tweets
         # the fields are : Name,sender_id,Tweet,TweetColour,id, type, timestamp, replyTo, source, pic, formatted_tweet
@@ -67,6 +81,8 @@ class account():
         self.osso_c = osso_c
         self.api = None
         self.connect()
+        self.dmnotify = pynotify.Notification("Witter","You have new DMs")
+        self.dmnotify.add_action("clicked","Show DMs", self.dm_callback)
 
     def connect(self):
         if self.accountdata.password:
@@ -224,7 +240,7 @@ class account():
             if (receive_count > 0):
                 note = osso.SystemNote(self.osso_c)
                 result = note.system_note_infoprint(str(receive_count) + " Tweets Received")
-
+                
         except IOError, e:
             print "error"
             msg = 'Error retrieving tweets '
@@ -304,8 +320,19 @@ class account():
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
-                note = osso.SystemNote(self.osso_c)
-                result = note.system_note_infoprint(str(receive_count) + " Mentions Received")
+                #note = osso.SystemNote(self.osso_c)
+                #result = note.system_note_infoprint(str(receive_count) + " Mentions Received")
+                n = pynotify.Notification("Witter","You have "+str(receive_count)+" new mentions")
+                n.set_urgency(pynotify.URGENCY_CRITICAL)
+                icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
+
+                n.set_icon_from_pixbuf(icon)
+                rpc = osso.Rpc(self.osso_c)
+                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
+                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
+                #n.attach_to_widget(self.controller.ui.window)
+                n.add_action("clicked","Show DMs", self.mentions_callback)
+                n.show()
 
         except IOError, e:
             print "error"
@@ -377,9 +404,19 @@ class account():
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
-                note = osso.SystemNote(self.osso_c)
-                result = note.system_note_infoprint(str(receive_count) + " DMs Received")
+                #note = osso.SystemNote(self.osso_c)
+                #result = note.system_note_infoprint(str(receive_count) + " DMs Received")
+                #n = pynotify.Notification("Witter","You have "+str(receive_count)+" new DMs")
+                icon= gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
+                self.dmnotify.set_icon_from_pixbuf(icon)                
+                self.dmnotify.set_urgency(pynotify.URGENCY_CRITICAL)
+                rpc = osso.Rpc(self.osso_c)
+                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._ENABLE_LED,rpc_args=(self._LED_PATTERN,"",""),use_system_bus=True)
+                rpc.rpc_run(self._MCE_SERVICE, self._MCE_REQUEST_PATH,self._MCE_REQUEST_IF,self._VIBRATE,rpc_args=(self._VIBRATE_PATTERN,"",""),use_system_bus=True)
+                #dmnotify.add_action("clicked","Show DMs", self.dm_callback)
 
+                #n.attach_to_widget(self.controller.ui.window)
+                self.dmnotify.show()
         except IOError, e:
             print "error"
             msg = 'Error retrieving dms '
@@ -1060,4 +1097,10 @@ class account():
         return timestamp.strftime('%a, %b %d %Y %H:%M:%S')  # %Z (timezone) would be empty
 
 
+    def mentions_callback(self, args):
+        print "mentions callback"
+        self.controller.ui.switchViewTo(self.controller.ui.treeview,"mentions")
 
+    def dm_callback(self, args):
+        print "dms callback"
+        self.controller.ui.switchViewTo(self.controller.ui.treeview,"direct")
