@@ -442,6 +442,18 @@ class Witter():
                     if (token != "None"):
                         accData.access_token = oauthtwitter.oauth.OAuthToken.from_string(token)
                     accData.status = int(config.get("users", "status" + str(counter)))
+                    try:
+                        id = config.get("users", "last_id" + str(counter))
+                        if (id != "None"):
+                            accData.last_id = long(id)
+                        dmid = config.get("users", "last_dm_id" + str(counter))
+                        if (dmid != "None"):
+                            accData.last_dm_id = long(dmid)
+                        menid = config.get("users", "last_mention_id" + str(counter))
+                        if (menid != "None"):
+                            accData.last_mention_id = long(menid)
+                    except ConfigParser.NoOptionError:
+                        print "No stored ids from last run"
                     self.config.accountList.append(accData)
 
                     counter = counter + 1
@@ -488,6 +500,7 @@ class Witter():
             f.write("search = " + str(self.searchRefreshInterval) + "\n")
             f.write("[search]\n")
             f.write("search_terms = " + self.search_terms + "\n")
+            
     	except IOError, e:
     		print "failed to write config file"
         try:
@@ -510,6 +523,12 @@ class Witter():
                 else:
                     f3.write("oauthtoken" + str(counter) + " = None\n")
                 f3.write("status" + str(counter) + " = " + str(account.status) + "\n")
+                #todo output tne last used ids for timelines, for each account
+                #then restore them at start up and only ever fetch since latest
+                f3.write("last_id" + str(counter) + " = " + str(account.last_id) + "\n")
+                f3.write("last_dm_id" + str(counter) + " = " + str(account.last_dm_id) + "\n")
+                f3.write("last_mention_id" + str(counter) + " = " + str(account.last_mention_id) + "\n")
+
                 counter = counter + 1
 
             print "written config object to file"
